<?php

/**
 * Define Constants
 */
if ( ! defined( 'PRESLAV_PAGE_BASENAME' ) ) {
	define( 'PRESLAV_PAGE_BASENAME', 'preslav-doc' );
}
if ( ! defined( 'PRESLAV_THEME_DETAILS' ) ) {
	define( 'PRESLAV_THEME_DETAILS', 'https://nasiothemes.com/themes/preslav/' );
}
if ( ! defined( 'PRESLAV_THEME_DEMO' ) ) {
	define( 'PRESLAV_THEME_DEMO', 'https://preslav-demo.nasiothemes.com/' );
}
if ( ! defined( 'PRESLAV_THEME_OPTIONS' ) ) {
	define( 'PRESLAV_THEME_OPTIONS', esc_url ( admin_url( '/customize.php' ) ) );
}
if ( ! defined( 'PRESLAV_THEME_VIDEO_GUIDE' ) ) {
	define( 'PRESLAV_THEME_VIDEO_GUIDE', 'https://www.youtube.com/watch?v=hjwRQlKZjPw&t' );
}
if ( ! defined( 'PRESLAV_THEME_FEATURES' ) ) {
	define( 'PRESLAV_THEME_FEATURES', 'https://nasiothemes.com/themes/preslav/#features' );
}
if ( ! defined( 'PRESLAV_THEME_DOCUMENTATION_URL' ) ) {
	define( 'PRESLAV_THEME_DOCUMENTATION_URL', 'https://nasiothemes.com/2023/06/29/preslav-theme-documentation/' );
}
if ( ! defined( 'PRESLAV_THEME_SUPPORT_FORUM_URL' ) ) {
	define( 'PRESLAV_THEME_SUPPORT_FORUM_URL', 'https://wordpress.org/support/theme/preslav/' );
}
if ( ! defined( 'PRESLAV_THEME_REVIEW_URL' ) ) {
	define( 'PRESLAV_THEME_REVIEW_URL', 'https://wordpress.org/support/theme/preslav/reviews/#new-post' );
}
if ( ! defined( 'PRESLAV_THEME_UPGRADE_URL' ) ) {
	define( 'PRESLAV_THEME_UPGRADE_URL', 'https://nasiothemes.com/themes/preslav/' );
}
if ( ! defined( 'PRESLAV_THEME_DEMO_IMPORT_URL' ) ) {
	define( 'PRESLAV_THEME_DEMO_IMPORT_URL', false );
}
/**
 * Specify Hooks/Filters
 */
add_action( 'admin_menu', 'preslav_add_menu' );
/**
 * The admin menu pages
 */
function preslav_add_menu() {
	add_theme_page(
		__( 'Preslav Theme', 'preslav' ),
		__( 'Preslav Theme', 'preslav' ),
		'edit_theme_options',
		PRESLAV_PAGE_BASENAME,
		'preslav_settings_page_doc'
	);
}

/*
 * Theme Documentation Page HTML
 *
 * @return echoes output
 */
function preslav_settings_page_doc() {
	// get the settings sections array
	$theme_data = wp_get_theme();
	?>
	
	<div class="nasiothemes-wrapper">
		<div class="nasiothemes-header">
			<div id="nasiothemes-theme-info">
				<div class="nasiothemes-message-image">
					<img class="nasiothemes-screenshot" src="
					<?php echo esc_url( get_template_directory_uri() ); ?>/admin/img/theme-logo.jpg" alt="
					<?php esc_attr_e( 'Preslav Theme Screenshot', 'preslav' ); ?>" />
				</div><!-- ws fix
				--><p>
						<?php
						echo sprintf(
								/* translators: Theme name and version */
							__( '<span class="theme-name">%1$s Theme</span> <span class="theme-version">(version %2$s)</span>', 'preslav' ),
							esc_html( $theme_data->name ),
							esc_html( $theme_data->version )
						);
						?>
					</p>
					<p class="theme-buttons">
						<a class="button button-primary" href="<?php echo esc_url( PRESLAV_THEME_DETAILS ); ?>" rel="noopener" target="_blank">
							<?php esc_html_e( 'Theme Homepage', 'preslav' ); ?>
						</a>
						<a class="button button-primary" href="<?php echo esc_url( PRESLAV_THEME_OPTIONS ); ?>" rel="noopener" target="_blank">
							<?php esc_html_e( 'Theme Options', 'preslav' ); ?>
						</a>
						<a class="button button-primary nasiothemes-button nasiothemes-button-youtube" href="
							<?php echo esc_url( PRESLAV_THEME_VIDEO_GUIDE ); ?>" rel="noopener" target="_blank"><span class="dashicons dashicons-youtube"></span> 
							<?php esc_html_e( 'Theme Video Tutorial', 'preslav' ); ?>
						</a>
					</p>
			</div><!-- .nasiothemes-header -->
		
		<div class="nasiothemes-documentation">

			<ul class="nasiothemes-doc-columns clearfix">
				<li class="nasiothemes-doc-column nasiothemes-doc-column-1">
					<div class="nasiothemes-doc-column-wrapper">
						<div class="doc-section">
							<h3 class="column-title"><span class="nasiothemes-icon dashicons dashicons-editor-help"></span><span class="nasiothemes-title-text">
							<?php
							esc_html_e( 'Documentation and Support', 'preslav' );
							?>
							</span></h3>
							<div class="nasiothemes-doc-column-text-wrapper">
								<p>
								<?php echo sprintf(
									/* translators: Theme name and link to WordPress.org Support forum for the theme */
									__( 'Please check the theme documentation before using the theme. Support for %1$s Theme is provided in the official WordPress.org community support forum. ', 'preslav' ),
									esc_html( $theme_data->name )
								);?>
								</p>
								<p class="doc-buttons">
									<a class="button button-primary" href="<?php echo esc_url( PRESLAV_THEME_DOCUMENTATION_URL );?>" rel="noopener" target="_blank">
									<?php esc_html_e( 'View Preslav Documentation', 'preslav' ); ?>
									</a>
								<?php if ( PRESLAV_THEME_SUPPORT_FORUM_URL ) { ?>
									 <a class="button button-secondary" href="<?php echo esc_url( PRESLAV_THEME_SUPPORT_FORUM_URL ); ?>" rel="noopener" target="_blank">
									<?php esc_html_e( 'Go to Preslav Support Forum', 'preslav' );
									?>
									</a>
									<?php
								} ?>
								</p>
							</div><!-- .nasiothemes-doc-column-text-wrapper-->
						</div><!-- .doc-section -->
						<div class="doc-section">
							<h3 class="column-title"><span class="nasiothemes-icon dashicons dashicons-editor-help"></span><span class="nasiothemes-title-text">
								<?php esc_html_e( 'FAQ', 'preslav' ); ?></span>
							</h3>
							<div class="nasiothemes-doc-column-text-wrapper">
								<strong><?php esc_html_e( '1. Where are the theme options?', 'preslav' ); ?></strong>
								<p><i><?php esc_html_e( 'Please navigate to Appearance => Customize and customize the theme to taste.', 'preslav' ); ?></i></p>
								<br>
								<strong><?php esc_html_e( '2. Can I add demo content for an easier start with the theme?', 'preslav' ); ?></strong>
								<p><i><?php esc_html_e( 'Yes, if you haven\'t added any content yet, you can go Appearance => Customize and you will load the starter content. If you have already added posts or pages, you can use the block patterns that are included in this theme.', 'preslav' ); ?></i></p>
								<br>
								<strong><?php esc_html_e( '3. Where are the custom block patterns?', 'preslav' ); ?></strong>
								<p><i><?php esc_html_e( 'In the WordPress admin, create or edit a page, then click on the plus icon in the top left corner of the Gutenberg editor. From there, navigate to the "Patterns" tab and select "Preslav" from the pattern dropdown.', 'preslav' ); ?></i></p>
								<br>
								<strong><?php esc_html_e( '4. Can I make the header to look like the theme screenshot?', 'preslav' ); ?></strong>
								<p><i><?php esc_html_e( 'That is easy, the header is registered as a block pattern in the category “Preslav”. Create or edit a page, import the pattern and you are all set.', 'preslav' ); ?></i></p>
								<br>
								<strong><?php esc_html_e( '5. Can I make a website that looks exactly like the theme demos?', 'preslav' ); ?></strong>
								<p><i><?php esc_html_e( 'Absolutely! all you need to do is upgrade to Preslav PRO and run the one-click demo import.', 'preslav' ); ?></i></p>
								<br>
								<strong><?php esc_html_e( '6. I have already purchased the premium version. How do I install and activate it?', 'preslav' ); ?></strong>
								<p><i><?php esc_html_e( 'To install the Preslav Pro theme, go to Appearance => Themes => Add new and upload the zip file that you have received upon theme purchase. To activate it, hover over Preslav Pro theme from the theme list on the same page and click "Activate". Finally, you will be asked to enter a license key that you have received by email.', 'preslav' ); ?></i></p>
								<br>
							</div><!-- .nasiothemes-doc-column-text-wrapper-->
						</div><!-- .doc-section -->
						<div class="doc-section">
							<h3 class="column-title"><span class="nasiothemes-icon dashicons dashicons-youtube"></span><span class="nasiothemes-title-text">
							    <?php esc_html_e( 'Theme Video Tutorial', 'preslav' ); ?></span>
                            </h3>
							<div class="nasiothemes-doc-column-text-wrapper">
								<p><strong><?php esc_html_e('Click the image below to open the video guide in a new browser tab.','preslav'); ?></strong></p>
								<p><a href="<?php echo esc_url(PRESLAV_THEME_VIDEO_GUIDE); ?>" rel="noopener" target="_blank"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/admin/img/video-preview.jpg" class="video-preview" alt="<?php esc_attr_e('Preslav Theme Video Tutorial','preslav'); ?>" /></a></p>
							</div><!-- .nasiothemes-doc-column-text-wrapper-->

						</div><!-- .doc-section -->
						
                        <div class="doc-section">
							<h3 class="column-title"><span class="nasiothemes-icon dashicons dashicons-awards"></span><span class="nasiothemes-title-text">
							<?php esc_html_e( 'Leave a Review', 'preslav' );?>
							</span></h3>
							<div class="nasiothemes-doc-column-text-wrapper">
								<p><?php esc_html_e( 'If you enjoy using Preslav Theme, please leave a review for it on WordPress.org. It encourages us continue providing updates and support for it.', 'preslav' );?></p>
								<p class="doc-buttons">
                                    <a class="button button-primary" href="<?php echo esc_url( PRESLAV_THEME_REVIEW_URL );?>" rel="noopener" target="_blank">
                                        <?php esc_html_e( 'Write a Review for Preslav', 'preslav' );?>
                                    </a>
                                </p>
							</div><!-- .nasiothemes-doc-column-text-wrapper-->
						</div><!-- .doc-section -->
					</div><!-- .nasiothemes-doc-column-wrapper -->
				</li><!-- .nasiothemes-doc-column --><li class="nasiothemes-doc-column nasiothemes-doc-column-2">
				<div class="nasiothemes-doc-column-wrapper">
						<?php

						if ( PRESLAV_THEME_UPGRADE_URL ) {
							?>
						<div class="doc-section">
							<h3 class="column-title"><span class="nasiothemes-icon dashicons dashicons-cart"></span><span class="nasiothemes-title-text">
							<?php esc_html_e( 'Upgrade to Preslav PRO', 'preslav' );
							?>
							</span>
                            </h3>
							<div class="nasiothemes-doc-column-text-wrapper">
								<p>
                                    <?php echo sprintf(
                                        /* translators: Theme name and link to WordPress.org Support forum for the theme */
                                        __( 'If you like the free version of %1$s Theme, you will love the PRO version.', 'preslav' ),
                                        esc_html( $theme_data->name )
                                    );
                                    ?>
								</p>
								<p>
								<?php esc_html_e( 'You will be able to create an even more unique website using the additional functionalities and customization options available in the pro version.', 'preslav' );
								?>
								<br>
								<p class="doc-buttons"><a class="button button-primary" href="
								<?php echo esc_url( PRESLAV_THEME_UPGRADE_URL );
								?>
								" rel="noopener" target="_blank">
								<?php esc_html_e( 'Upgrade to Preslav PRO', 'preslav' );
								?>
								</a>
								<?php

								if ( PRESLAV_THEME_FEATURES ) {
									?>
									<a class="button button-primary nasiothemes-button nasiothemes-button-youtube" href="
									<?php echo esc_url( PRESLAV_THEME_FEATURES );
									?>
									" rel="noopener" target="_blank">
									<?php esc_html_e( 'View Full List of Features', 'preslav' );
									?>
									</a>
									<?php
								}

								?>
								</p>

								<table class="theme-comparison-table">
									<tr>
										<th class="table-feature-title">
											<?php esc_html_e( 'Feature', 'preslav' ); ?>
										</th>
										<th class="table-lite-value">
											<?php esc_html_e( 'Preslav', 'preslav' ); ?>
										</th>
										<th class="table-pro-value">
											<?php esc_html_e( 'Preslav PRO', 'preslav' ); ?>
										</th>
									</tr>
									<tr>
										<td><div class="nasio-tooltip"><span class="dashicons dashicons-editor-help"></span><span class="nasio-tooltiptext">
											<?php esc_html_e( 'Import demo content with posts, pages and images for an easier start with the theme with a single click.', 'preslav' ); ?></span></div>
												<?php esc_html_e( 'One Click Demo Import', 'preslav' );?>
										</td>
										<td><span class="dashicons dashicons-minus"></span></td>
										<td><span class="dashicons dashicons-yes-alt"></span></td>
									</tr>
									<tr>
										<td><div class="nasio-tooltip"><span class="dashicons dashicons-editor-help"></span><span class="nasio-tooltiptext">
											<?php esc_html_e( 'Add ready to use gutenberg block patterns with predefined content for an easier start with the theme.', 'preslav' ); ?></span></div>
											<?php esc_html_e( 'Block Patterns', 'preslav' ); ?>
										</td>
										<td>
											<span class="dashicons dashicons-yes-alt"></span>
											<?php esc_html_e( '10', 'preslav' ); ?>
										</td>
										<td>
											<span class="dashicons dashicons-yes-alt"></span>
											<?php esc_html_e( '14', 'preslav' ); ?>
										</td>
									</tr>
									<tr>
										<td>
											<div class="nasio-tooltip"><span class="dashicons dashicons-editor-help"></span><span class="nasio-tooltiptext">
												<?php esc_html_e( 'Engage with your visitors by adding interactive content on top of the website.', 'preslav' ); ?></span>
											</div>
											<?php esc_html_e( 'Promo Banner', 'preslav' ); ?>
										</td>
										<td><span class="dashicons dashicons-minus"></span></td>
										<td><span class="dashicons dashicons-yes-alt"></span></td>
									</tr>
									<tr>
										<td><div class="nasio-tooltip"><span class="dashicons dashicons-editor-help"></span><span class="nasio-tooltiptext">
											<?php esc_html_e( 'Customize the slider directly from the theme Customizer. No coding skills needed!', 'preslav' ); ?>
											</span></div>
											<?php esc_html_e( 'Responsive slider', 'preslav' ); ?>
										</td>
										<td><span class="dashicons dashicons-minus"></span></td>
										<td><span class="dashicons dashicons-yes-alt"></span></td>
									</tr>
									<tr>
										<td><div class="nasio-tooltip"><span class="dashicons dashicons-editor-help"></span><span class="nasio-tooltiptext">
										<?php esc_html_e( 'Remove theme author credits and add your own text here. Customize the colors of the footer elements directly from the theme customizer. No coding skills needed!', 'preslav' );
										?>
										</span></div>
										<?php esc_html_e( 'Edit Footer Credits', 'preslav' );
										?>
										</td>
										<td><span class="dashicons dashicons-minus"></span></td>
										<td><span class="dashicons dashicons-yes-alt"></span></td>
									</tr>
									<tr>
										<td><div class="nasio-tooltip"><span class="dashicons dashicons-editor-help"></span><span class="nasio-tooltiptext">
                                            <?php esc_html_e( 'Impress your visitors by converting your mouse into a transparent or filled cursor.', 'preslav' );
                                            ?>
                                            </span></div>
                                            <?php esc_html_e( 'Custom cursor', 'preslav' );
                                            ?>
										</td>
										<td><span class="dashicons dashicons-minus"></span></td>
										<td><span class="dashicons dashicons-yes-alt"></span></td>
									</tr>
									<tr>
										<td>
										<?php esc_html_e( 'Support', 'preslav' );
										?>
										</td>
										<td><div class="nasio-tooltip">
                                            <?php esc_html_e( 'Nonpriority', 'preslav' );
                                            ?>
                                            <span class="nasio-tooltiptext">
                                            <?php esc_html_e( 'Support is provided in the WordPress.org community forums.', 'preslav' );
                                            ?>
                                            </span></div>
                                        </td>
										<td><div class="nasio-tooltip"><strong>
                                            <?php esc_html_e( 'Priority Support', 'preslav' );
                                            ?>
                                            </strong><span class="nasio-tooltiptext">
                                            <?php esc_html_e( 'Quick and friendly support is available via email', 'preslav' );
                                            ?>
                                            </span></div>
                                        </td>
									</tr>
									<tr>
										<td colspan="3" style="text-align: center;"><a class="button button-primary" href="
										<?php echo esc_url( PRESLAV_THEME_UPGRADE_URL );
										?>
											" rel="noopener" target="_blank">
											<?php esc_html_e( 'Upgrade to Preslav PRO', 'preslav' );
											?>
											</a>
										</td>
									</tr>
								</table>

							</div><!-- .nasiothemes-doc-column-text-wrapper-->
						</div><!-- .doc-section -->
							<?php
						}

						?>
					</div><!-- .nasiothemes-doc-column-wrapper -->
				</li><!-- .nasiothemes-doc-column -->
			</ul><!-- .nasiothemes-doc-columns -->

		</div><!-- .nasiothemes-documentation -->

	</div><!-- .nasiothemes-wrapper -->

	<?php
}
