<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package preslav
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'preslav' ); ?></a>
	<header id="masthead" class="site-header">
	<?php
	if ( preslav_has_secondary_menu() ) : ?>
		<nav id="top-navigation" class="top-menu site-menu">
			<div class="header-content-wrapper">
				<?php
				/**
				 * preslav_top menu_hook
				 *
				 * @since 1.0.0
				 * @hooked preslav_top_menu
				*/
				do_action( 'preslav_top_menu_hook' ); ?>
			</div>
		</nav>
		<?php endif; ?>
		<div class="main-navigation-container">
			<div class="header-content-wrapper">
				<div class="site-branding">
					<?php the_custom_logo();
					preslav_dark_mode_logo();
					if ( display_header_text() == true ) : ?>
					<div class="site-meta">
						<div class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></div>
						<?php if ( get_bloginfo( 'description', 'display' ) || is_customize_preview() ) :
							?>
							<p class="site-description"><?php echo get_bloginfo( 'description', 'display') // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
						<?php endif; ?>
					</div>
					<?php endif; ?>
				</div><!-- .site-branding -->

				<nav id="main-navigation" class="main-navigation site-menu">
					<button class="menu-toggle" data-toggle="collapse" aria-controls="top-menu" aria-expanded="false" aria-label="<?php _e('Toggle Navigation', 'preslav')?>">
						<span class="menu-toggle-icon">
							<input class="burger-check" id="burger-check" type="checkbox"><label for="burger-check" class="burger"></label>
						</span>
					</button>
					<?php
					/**
					 * preslav_primary_menu_hook
					 * 
					 * @since 1.0.0
					 * @hooked preslav_primary_menu
					 */
					do_action( 'preslav_primary_menu_hook' ); ?>
				</nav><!-- #site-navigation -->
			</div>
		</div>
		<?php
		/**
		 * preslav_progress_bar_hook
		 * 
		 * @since 1.0.0
		 * @hooked preslav_progress_bar
		 */
		do_action( 'preslav_progress_bar_hook' );
		/**
		 * preslav_header_image_hook
		 * 
		 * @since 1.1.2
		 * @hooked preslav_header_image
		 */
		do_action( 'preslav_header_image_hook' ); ?>
	</header><!-- #masthead -->
	