<?php
/**
 * Sample implementation of the Custom Header feature
 *
 * This theme does not implement Custom Header Image.
 * Instead, the theme focuses on allowing editors to create more dynamic content with Gutenberg or any other WordPress editor
 * The theme still displays a custom header with site title, description and menu.
 *
	<?php the_header_image_tag(); ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package preslav
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses preslav_header_style()
 */

register_default_headers(
	array(
		'default-image' => array(
			'url'           => get_template_directory_uri() . '/assets/img//patterns/contact-us.jpg',
			'thumbnail_url' => get_template_directory_uri() . '/assets/img//patterns/contact-us.jpg',
			'description'   => __( 'Default Header Image', 'preslav' ),
		),
	)
);

/* Create the header image object */
if ( ! function_exists( 'preslav_custom_header_setup' ) ) {
	function preslav_custom_header_setup() {
		add_theme_support(
			'custom-header',
			apply_filters(
				'preslav_custom_header_args',
				array(
					'default-text-color' => '333',
					// 'default-image'      => get_template_directory_uri() . '/assets/img//patterns/contact-us.jpg',
					'flex-width'         => true,
					'flex-height'        => true,
					'width'              => 2200,
					'wp-head-callback'   => 'preslav_header_image_css',
				)
			)
		);
	}
}
add_action( 'after_setup_theme', 'preslav_custom_header_setup' );


/* Add control to Show or hide the header image on Homepage */

function preslav_header_image_options_customize_register( $wp_customize ) {

		// Header Image Position
	$wp_customize->add_setting(
		'header_background_position',
		array(
			'default'           => 'top',
			'sanitize_callback' => 'preslav_sanitize_select',
			'transport'         => 'postMessage',
		)
	);

	$wp_customize->add_control(
		'header_background_position',
		array(
			'label'       => esc_html__( 'Header Background Position', 'preslav' ),
			'section'     => 'header_image',
			'description' => esc_html__( 'Choose how you want to position the header image.', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'top'    => esc_html( 'top' ),
				'center' => esc_html( 'center' ),
				'bottom' => esc_html( 'bottom' ),
			),
			'active_callback' => 'has_header_image',
		)
	);

	$wp_customize->add_setting(
		'header_gradient_density',
		array(
			'default'           => '6',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'header_gradient_density',
		array(
			'label'       => __( 'Header Image Gradient Density', 'preslav' ),
			'description' => __( 'Control the gradient density. From 0 to 9. Default is 6. Set it to 0 to remove the entire gradient.', 'preslav' ),
			'section'     => 'header_image',
			'type'        => 'range',
			'input_attrs' => array(
				'min'  => 0,
				'max'  => 9,
				'step' => 1,
			),
			'active_callback' => 'has_header_image',
		)
	);

	$wp_customize->add_setting(
		'preslav_header_title',
		array(
			'default'           => esc_html__( 'CREATE A WEBSITE THAT CONVERTS', 'preslav' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'preslav_header_title',
		array(
			'label'           => esc_html__( 'Header Title', 'preslav' ),
			'section'         => 'header_image',
			'description'     => esc_html__( 'Change the default text of header title.', 'preslav' ),
			'type'            => 'text',
			'active_callback' => 'has_header_image',
		)
	);

	$wp_customize->add_setting(
		'preslav_header_description',
		array(
			'default'           => esc_html__( 'Making the first step has never been easy', 'preslav' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'preslav_header_description',
		array(
			'label'           => esc_html__( 'Header Description', 'preslav' ),
			'section'         => 'header_image',
			'description'     => esc_html__( 'Change the default text of the header description.', 'preslav' ),
			'type'            => 'text',
			'active_callback' => 'has_header_image',
		)
	);

	/*
	 * CALL TO ACTION
	 */

	$wp_customize->add_setting(
		'call_to_action',
		array(
			'default'           => esc_html__( 'Get Started', 'preslav' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'call_to_action',
		array(
			'label'           => esc_html__( 'Button Text', 'preslav' ),
			'section'         => 'header_image',
			'description'     => esc_html__( 'Change the default text of the button.', 'preslav' ),
			'type'            => 'text',
			'active_callback' => 'has_header_image',
		)
	);

	// Banner Link
	$wp_customize->add_setting(
		'banner_link_one',
		array(
			'default'           => '#',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'banner_link_one',
		array(
			'label'           => esc_html__( 'Button Link', 'preslav' ),
			'section'         => 'header_image',
			'description'     => esc_html__( 'Add link to the button. You can link it to the About page or the Contact page or to a specific section from the Homepage.', 'preslav' ),
			'type'            => 'url',
			'active_callback' => 'has_header_image',
		)
	);

	$wp_customize->add_setting(
		'enable_header_text_animation',
		array(
			'default'           => 1,
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'enable_header_text_animation',
		array(
			'label'           => esc_html__( 'Enable text animation', 'preslav' ),
			'section'         => 'header_image',
			'description'     => esc_html__( 'Uncheck this to disable the header text animation', 'preslav' ),
			'type'            => 'checkbox',
			'active_callback' => 'has_header_image',
		)
	);
}

add_action( 'customize_register', 'preslav_header_image_options_customize_register' );

if ( ! function_exists( 'preslav_header_style' ) ) :
	 /**
	  * Styles the header image and text displayed on the blog.
	  *
	  * @see preslav_custom_header_setup().
	  */
	function preslav_header_style() {
		$header_text_color = get_header_textcolor();

		/*
		* If no custom options for text are set, let's bail.
		* get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
		*/
		if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
			return;
		}

		// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">
		 <?php
			// Has the text been hidden?
			if ( ! display_header_text() ) :
				?>
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
				}
				  <?php
					// If the user has set a custom color for the text use that.
		 else :
				?>
			.site-title a,
			.site-description {
				color: #<?php echo esc_attr( $header_text_color ); ?>;
			}
		 <?php endif; ?>
		</style>
		 <?php
	}
endif;


/* Style the custom header image */

function preslav_header_image_css() {
	$gradient_first_color  = get_theme_mod( 'preslav_gradient_color_one', '#09114e' );
	$gradient_second_color = get_theme_mod( 'preslav_gradient_color_two', '#1656d1' );
	$gradient_density      = get_theme_mod( 'header_gradient_density', '6' );
	$position              = get_theme_mod( 'header_background_position', 'top' );
	$overlay               = get_theme_mod( 'cover_template_overlay_opacity', '1' );

	?>
	
<style type="text/css">

	<?php if ( has_header_image() && is_front_page() ) : ?>

	.header-image-wrapper {
		background-image: url(<?php header_image(); ?>);
		height: 420px;
		background-repeat: no-repeat;
		background-size: cover;
		background-position: <?php echo esc_attr( $position ); ?>;
		position: relative;
		margin-bottom: 2rem;
	}

		<?php if ( $gradient_density ) : ?>
		.header-image-wrapper::before {
			background: linear-gradient(135deg, <?php echo esc_attr( preslav_hex_to_rgba( $gradient_first_color, $gradient_density / 10 ) ); ?>, <?php echo esc_attr( preslav_hex_to_rgba( $gradient_second_color, $gradient_density / 10 ) ); ?>);
			width: 100%;
			height: 100%;
			display: inline-block;
			content: "";
		} 
			<?php
		endif;

	endif;
	?>

</style>
	<?php
}
