<?php
/**
 * Customizer callback functions for active_callback.
 *
 * Use these functions to show or hide customizer options.
 *
 * @package preslav
 */


 /**
  * Get lighter/darker color when given a hex value.
  *
  * @param string $hex Get the hex value from the customizer api.
  * @param int    $steps Steps should be between -255 and 255. Negative = darker, positive = lighter.
  * @link https://wordpress.org/themes/scaffold
  * @license GPL-2.0-or-later
  * @since 0.0.1
  */

  function preslav_brightness( $hex, $steps ) {

	$steps = max( -255, min( 255, $steps ) );

	// Normalize into a six character long hex string.
	$hex = str_replace( '#', '', $hex );
	if ( strlen( $hex ) === 3 ) {
		$hex = str_repeat( substr( $hex, 0, 1 ), 2 ) . str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 );
	}

	// Split into three parts: R, G and B.
	$color_parts = str_split( $hex, 2 );
	$return      = '#';

	foreach ( $color_parts as $color ) {
		$color   = hexdec( $color ); // Convert to decimal.
		$color   = max( 0, min( 255, $color + $steps ) ); // Adjust color.
		$return .= str_pad( dechex( $color ), 2, '0', STR_PAD_LEFT ); // Make two char hex code.
	}

	return sanitize_hex_color( $return );
}

/**
 * Convert given hex values to rgb or rgba values. Useful to convert values stored in the theme customizer.
 *
 * @param string $hex Get the hex value from the customizer api.
 * @param int    $alpha Add Opacity
 * @link https://stackoverflow.com/questions/15202079/convert-hex-color-to-rgb-values-in-php
 * @since 1.1.2
 */

 function preslav_hex_to_rgba( $hex, $alpha = false ) {
	$hex      = str_replace( '#', '', $hex );
	$length   = strlen( $hex );
	$rgb['r'] = hexdec( $length == 6 ? substr( $hex, 0, 2 ) : ( $length == 3 ? str_repeat( substr( $hex, 0, 1 ), 2 ) : 0 ) );
	$rgb['g'] = hexdec( $length == 6 ? substr( $hex, 2, 2 ) : ( $length == 3 ? str_repeat( substr( $hex, 1, 1 ), 2 ) : 0 ) );
	$rgb['b'] = hexdec( $length == 6 ? substr( $hex, 4, 2 ) : ( $length == 3 ? str_repeat( substr( $hex, 2, 1 ), 2 ) : 0 ) );
	if ( $alpha ) {
		$rgb['a'] = $alpha;
	}
	return implode( array_keys( $rgb ) ) . '(' . implode( ', ', $rgb ) . ')';
}

/*
 * Callback to show excerpt or full post content on archive pages
 * Based on theme customizer
 */
function preslav_is_excerpt() {
	$preslav_post_excerpt = get_theme_mod( 'post_archives_content', 1 );
	if ( $preslav_post_excerpt ) :
		return true;
	else :
		return false;
	endif;
}

function preslav_has_secondary_menu() {
	return get_theme_mod( 'has_secondary_menu', true );
}

function preslav_is_fixed_header() {
	return ( get_theme_mod( 'header-menu-position', 'fixed' ) == 'fixed' );
}

function preslav_is_sticky_header() {
	return ( get_theme_mod( 'header-menu-position', 'sticky' ) == 'sticky' );
}

function preslav_is_static_header() {
	return get_theme_mod( 'header-menu-position', 'sticky' ) == 'static';
}

function preslav_add_customizer_class( $class ) {
	return esc_attr( ! $class && is_customize_preview() ? ' hide' : '' );
}

function preslav_has_multicolumn_layout() {
	return get_theme_mod( 'post_archives_columns', '1' ) !== '1';
}

function preslav_topmenu_has_wc_items() {
	return true;
}