<?php

/**
 * Register Blog Settings Section in the theme customizer.
 *
 * @package preslav
 */
function preslav_register_blog_theme_customizer( $wp_customize ) {
	$wp_customize->add_section(
		'blog_options',
		array(
			'title'       => esc_html__( 'Blog Settings', 'preslav' ),
			'description' => esc_html__( 'Customize the way blog posts are displayed. More customization options - go pro version.', 'preslav' ),
		)
	);

	// Post Meta Before Post Content
	$wp_customize->add_setting(
		'show_post_meta_before_post_content',
		array(
			'default'           => 'show_post_date,show_post_author',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Preslav_Pill_Checkbox_Custom_Control(
			$wp_customize,
			'show_post_meta_before_post_content',
			array(
				'label'       => esc_html__( 'Toggle Post Meta Before Post Content', 'preslav' ),
				'description' => esc_html__( 'Customize the way blog posts meta information in post archives and single blog posts are displayed. You can choose to show or hide the post meta before the post content. Drag and drop the boxes to chage the post meta order.', 'preslav' ),
				'section'     => 'blog_options',
				'input_attrs' => array(
					'sortable'  => true,
					'fullwidth' => true,
				),
				'choices'     => array(
					'show_post_date'       => esc_html__( 'Show Post Date', 'preslav' ),
					'show_post_author'     => esc_html__( 'Show Post Author', 'preslav' ),
					'show_post_categories' => esc_html__( 'Show Post Categories', 'preslav' ),
					'show_post_tags'       => esc_html__( 'Show Post Tags', 'preslav' ),
					'show_post_comments'   => esc_html__( 'Show Number of Comments', 'preslav' ),
				),
			)
		)
	);

	// Post Meta After Post Content
	$wp_customize->add_setting(
		'show_post_meta_after_post_content',
		array(
			'default'           => 'show_post_categories,show_post_tags,show_post_comments',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Preslav_Pill_Checkbox_Custom_Control(
			$wp_customize,
			'show_post_meta_after_post_content',
			array(
				'label'       => esc_html__( 'Toggle Post Meta After Post Content', 'preslav' ),
				'description' => esc_html__( 'Customize the way blog posts meta information in post archives and single blog posts are displayed. You can choose to show or hide the post meta after the post content. Drag and drop the boxes to chage the post meta order.', 'preslav' ),
				'section'     => 'blog_options',
				'input_attrs' => array(
					'sortable'  => true,
					'fullwidth' => true,
				),
				'choices'     => array(
					'show_post_date'       => esc_html__( 'Show Post Date', 'preslav' ),
					'show_post_author'     => esc_html__( 'Show Post Author', 'preslav' ),
					'show_post_categories' => esc_html__( 'Show Post Categories', 'preslav' ),
					'show_post_tags'       => esc_html__( 'Show Post Tags', 'preslav' ),
					'show_post_comments'   => esc_html__( 'Show Number of Comments', 'preslav' ),
				),
			)
		)
	);

	// Add Settings and Controls for blog content.
	$wp_customize->add_setting(
		'post_archives_content',
		array(
			'default'           => 1,
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_archives_content',
		array(
			'label'       => esc_html__( 'Blog Excerpts', 'preslav' ),
			'description' => esc_html__( 'Show post excerpts instead of full content for your post archives.', 'preslav' ),
			'section'     => 'blog_options',
			'type'        => 'checkbox',
		)
	);
	// Add Setting and Control for Excerpt Length.
	$wp_customize->add_setting(
		'preslav_excerpt_length',
		array(
			'default'           => 55,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'preslav_excerpt_length',
		array(
			'label'           => esc_html__( 'Post Excerpt Length', 'preslav' ),
			'section'         => 'blog_options',
			'type'            => 'number',
			'input_attrs'     => array(
				'min'  => 10,
				'max'  => 55,
				'step' => 1,
			),
			'description'     => esc_html__( 'Enter a number between 10 and 55. Default is 55.', 'preslav' ),
			'active_callback' => 'preslav_is_excerpt',
		)
	);

	$wp_customize->add_setting(
		'content_layout',
		array(
			'default'           => 'seperate_containers',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'content_layout',
		array(
			'label'       => esc_html__( 'Post Content Wrap', 'preslav' ),
			'section'     => 'blog_options',
			'description' => esc_html__( 'Wrap posts in a card or leave them as plain text.', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'one_container'       => esc_html__( 'No Wrap', 'preslav' ),
				'seperate_containers' => esc_html__( 'Seperate Containers', 'preslav' ),
			),
		)
	);

	$wp_customize->add_setting(
		'post_archives_columns',
		array(
			'default'           => '1',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'post_archives_columns',
		array(
			'label'           => esc_html__( 'Post Archives Layout', 'preslav' ),
			'section'         => 'blog_options',
			'description'     => esc_html__( 'Display posts in post archives in a single or multi-column layout', 'preslav' ),
			'type'            => 'select',
			'choices'         => array(
				'1' => esc_html__( 'One Column', 'preslav' ),
				'2' => esc_html__( 'Two Columns', 'preslav' ),
				'3' => esc_html__( 'Three Columns', 'preslav' ),
				'4' => esc_html__( 'Four Columns', 'preslav' ),
			),
			'active_callback' => 'preslav_is_excerpt',
		)
	);

	$wp_customize->add_setting(
		'post_archives_display',
		array(
			'default'           => 'grid',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'post_archives_display',
		array(
			'label'           => esc_html__( 'Post Archives Display', 'preslav' ),
			'section'         => 'blog_options',
			'description'     => esc_html__( 'Display post columns in a grid or masonry layout', 'preslav' ),
			'type'            => 'select',
			'choices'         => array(
				'grid'    => esc_html__( 'Grid', 'preslav' ),
				'masonry' => esc_html__( 'Masonry', 'preslav' ),
			),
			'active_callback' => 'preslav_has_multicolumn_layout',
		)
	);

	$wp_customize->add_setting(
		'post_loop_animation',
		array(
			'default'           => 'slide_up',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'post_loop_animation',
		array(
			'label'       => esc_html__( 'Post Loop Animation', 'preslav' ),
			'section'     => 'blog_options',
			'description' => esc_html__( 'Animate blog posts in post archives.', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'zoom_in'  => esc_html__( 'Zoom In Animation', 'preslav' ),
				'slide_up' => esc_html__( 'Slide Up Animation', 'preslav' ),
				'rotate'   => esc_html__( 'Rotate Text Animation', 'preslav' ),
				'disabled' => esc_html__( 'Disabled', 'preslav' ),
			),
		)
	);

	$wp_customize->add_setting(
		'post_archives_title_hover_animation',
		array(
			'default'           => 'underline',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'post_archives_title_hover_animation',
		array(
			'label'       => esc_html__( 'Post Archives Title Hover Animation', 'preslav' ),
			'section'     => 'blog_options',
			'description' => esc_html__( 'Choose an animation to display when hovering over a menu item. ', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'underline' => esc_html__( 'Underline', 'preslav' ),
				'disabled'  => esc_html__( 'Disabled', 'preslav' ),
			),
		)
	);

	$wp_customize->add_setting(
		'has_progress_bar',
		array(
			'default'           => true,
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'has_progress_bar',
		array(
			'label'       => esc_html__( 'Enable Progress Bar', 'preslav' ),
			'description' => esc_html__( 'Show post progress when you scroll down the blog post.', 'preslav' ),
			'section'     => 'blog_options',
			'type'        => 'checkbox',
		)
	);

}

add_action( 'customize_register', 'preslav_register_blog_theme_customizer' );

function preslav_customize_blog_css() {

	$content_layout        = get_theme_mod( 'content_layout', 'seperate_containers' );
	$post_archives_columns = get_theme_mod( 'post_archives_columns', '1' );
	$post_animation        = get_theme_mod( 'post_loop_animation', 'slide_up' );
	$post_title_animation  = get_theme_mod( 'post_archives_title_hover_animation', 'underline' );
	?>

<style type="text/css">

	<?php
	// Post title hover animation
	if ( $post_title_animation == 'underline' ) :
		?>
	@media (min-width: 54rem) {
		.preslav-post-container .entry-title a{
			background: linear-gradient(to right, CurrentColor 0%, CurrentColor 100%);
			background-size: 0 3px;
			background-repeat: no-repeat;
			background-position: left 100%;
			display: inline-block;
			transition: background-size 0.6s ease-in-out;
		}

		.preslav-post-container .entry-title a:hover {
			background-size: 100% 3px;
		}
	}
	<?php endif; ?>

	<?php if ( $content_layout == 'seperate_containers' ) : ?>
	body:not(.page) .hentry {
		margin: 1.25em 0 2em;
		padding: 1.5em 1em;
	}
	body:not(.page):not(.dark-mode) {
		background-color: #f7f8f9
	}
	body:not(.dark-mode) .main-navigation-container, body:not(.dark-mode).has-transparent-header .main-navigation-container.fixed-header {
		background-color: #fff;
	}
	body.has-transparent-header .main-navigation-container {
		background-color: transparent;
	}
	body:not(.page):not(.dark-mode) .hentry {
		background-color: #fff;
	}
	.dark-mode.single .entry-footer {
		  border-bottom: 0;
	}
	.dark-mode:not(.page) .hentry {
		box-shadow: 0 20px 80px 0 rgba(193, 199, 212, .1);
	}
		<?php
	endif;

	if ( $post_archives_columns == 2 ) :
		?>
	@media(min-width:54rem){
		.preslav-post-inner {
			display: grid;
			grid-template-columns: auto auto;
			grid-gap: 2rem;
		}
	}
	<?php elseif ( $post_archives_columns == 3 ) : ?>
	@media(min-width:54rem){
		.preslav-post-inner {
			display: grid;
			grid-template-columns: auto auto auto;
			grid-gap: 2rem;
		}
	}

	<?php elseif ( $post_archives_columns == 4 ) : ?>
	@media(min-width:54rem){
		.preslav-post-inner {
			display: grid;
			grid-template-columns: auto auto auto auto;
			grid-gap: 2rem;
		}
	}
		<?php
	endif;

	/* Post Loop Animation */
	if ( $post_animation !== 'disabled' ) :
		?>
	body:not(.page):not(.single) .hentry.animated {
		opacity: 1;
		<?php echo esc_attr( $post_animation == 'slide_up' ? 'transform: translate(0, 0);' : ( $post_animation == 'zoom_in' ? 'transform: scale3d(1, 1, 1);' : 'transform: rotateX(0);' ) ); ?>
		transform: rotateX(0);
	}

	body:not(.page):not(.single) .hentry {
		transition: all 0.6s ease-in-out;
		opacity: 0.35;
		<?php echo esc_attr( $post_animation == 'slide_up' ? 'transform: translate(0px, 3em);' : ( $post_animation == 'zoom_in' ? 'transform: scale3d(0.9, 0.9, 0.9);' : 'transform: perspective(2000px) rotateX(12deg);' ) ); ?>
	}

	<?php endif; ?>

</style>

	<?php

}
add_action( 'wp_head', 'preslav_customize_blog_css' );
