<?php

function preslav_customize_colors( $wp_customize ) {

	$wp_customize->get_section( 'colors' )->description = esc_html__( 'Customze the colors of the light theme mode. To customize the dark theme mode, go to the Night Mode section. Colors that are selected in the Block editor (Gutenberg) will not be affected.', 'preslav' );

	$wp_customize->add_setting(
		'primary_accent_color',
		array(
			'default'           => '#0e40f7',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'primary_accent_color',
			array(
				'label'   => esc_html__( 'Primary Accent Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	$wp_customize->add_setting(
		'secondary_accent_color',
		array(
			'default'           => '#ffd100',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'secondary_accent_color',
			array(
				'label'   => esc_html__( 'Secondary Accent Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	$wp_customize->add_setting(
		'preslav_gradient_color_one',
		array(
			'default'           => '#09114e',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'preslav_gradient_color_one',
			array(
				'label'       => esc_html__( 'Header Image Gradient Color One', 'preslav' ),
				'section'     => 'colors',
				'description' => esc_html__( 'To customize the header image, go to "Header Image" section.', 'preslav' ),
			)
		)
	);

	$wp_customize->add_setting(
		'preslav_gradient_color_two',
		array(
			'default'           => '#1656d1',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'preslav_gradient_color_two',
			array(
				'label'   => esc_html__( 'Header Image Gradient Color Two', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	// Headings Text Color
	$wp_customize->add_setting(
		'headings_text_color',
		array(
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'headings_text_color',
			array(
				'label'   => esc_html__( 'Headings Text Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	// Body Text Color
	$wp_customize->add_setting(
		'body_text_color',
		array(
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'body_text_color',
			array(
				'label'   => esc_html__( 'Body Text Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	$wp_customize->add_setting(
		'links_text_color',
		array(
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'links_text_color',
			array(
				'label'   => esc_html__( 'Links Text Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	$wp_customize->add_setting(
		'buttons_bgr_color',
		array(
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'buttons_bgr_color',
			array(
				'label'   => esc_html__( 'Buttons Background Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	$wp_customize->add_setting(
		'buttons_text_color',
		array(
			'default'           => '#404040',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'buttons_text_color',
			array(
				'label'   => esc_html__( 'Buttons Text Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	// Header text color
	$wp_customize->add_setting(
		'preslav_header_text_color',
		array(
			'default'           => '#000',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'preslav_header_text_color',
			array(
				'label'   => esc_html__( 'Primary Menu Text Color', 'preslav' ),
				'section' => 'colors',
			)
		)
	);

	// top menu background color
	$wp_customize->add_setting(
		'top-menu_bgr_color',
		array(
			'default'           => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'top-menu_bgr_color',
			array(
				'label'           => esc_html__( 'Top Bar Background Color', 'preslav' ),
				'section'         => 'colors',
				'active_callback' => 'preslav_has_secondary_menu',
			)
		)
	);

	// top menu text color
	$wp_customize->add_setting(
		'top-menu_text_color',
		array(
			'default'           => '#334142',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'top-menu_text_color',
			array(
				'label'           => esc_html__( 'Top Bar Text Color', 'preslav' ),
				'section'         => 'colors',
				'active_callback' => 'preslav_has_secondary_menu',
			)
		)
	);
}

add_action( 'customize_register', 'preslav_customize_colors', 10 );

function preslav_customize_colors_css() {

	$body_text_color     = get_theme_mod( 'body_text_color' );
	$headings_text_color = get_theme_mod( 'headings_text_color' );
	$links_text_color    = get_theme_mod( 'links_text_color' );
	$buttons_bgr_color   = get_theme_mod( 'buttons_bgr_color' );
	$buttons_text_color  = get_theme_mod( 'buttons_text_color', '#404040' );

	$primary_accent_color   = get_theme_mod( 'primary_accent_color', '#1656d1' );
	$secondary_accent_color = get_theme_mod( 'secondary_accent_color', '#ffd100' );

	?>
	
	<style>
	<?php if ( $body_text_color ) : ?> 
	body {
		color: <?php echo esc_attr( $body_text_color ); ?>;
	}
	<?php endif;

	if ( $headings_text_color ) : ?>
	h1, h2, h3, h4, h5, h6, .entry-title a, .entry-title a:hover, .entry-title a:focus{
		color: <?php echo esc_attr( $headings_text_color ); ?>;
	}
	<?php endif;
	
	if ( $links_text_color ) : ?>
	a {
		color: <?php echo esc_attr( $links_text_color ); ?>;
	}
	a:hover, a:active, a:focus {
		color: <?php echo esc_attr( preslav_brightness( $links_text_color, -25 ) ); // WPCS: XSS ok. ?>;
	}
	<?php endif; ?>
	body:not(.dark-mode) input[type="button"], 
	body:not(.dark-mode) input[type="reset"], 
	body:not(.dark-mode) [type="submit"]:not(.header-search-form button),
	.wp-block-button > .slider-button {
		background: <?php echo $buttons_bgr_color ? esc_attr( $buttons_bgr_color ) : esc_attr( $secondary_accent_color ); ?>;
		color: <?php echo esc_attr( $buttons_text_color ); ?>;
	}

	<?php if ($buttons_bgr_color) : ?>
	body:not(.dark-mode) .wp-element-button, 
	body:not(.dark-mode) .wp-block-button__link {
		background: <?php echo esc_attr( $buttons_bgr_color ); ?>;
	}
	<?php endif; ?>
	.back-to-top,
	.dark-mode .back-to-top,
	.navigation .page-numbers:hover,
	.navigation .page-numbers.current  {
		background: <?php echo $buttons_bgr_color ? esc_attr( preslav_brightness( $buttons_bgr_color, -50 ) ) : esc_attr( preslav_brightness( $secondary_accent_color, -50 ) ); ?>
	}

	.progress-bar {
		background: <?php echo esc_attr( preslav_brightness( $secondary_accent_color, -50 ) ); // WPCS: XSS ok. ?>;
	}

	.preloader .bounce1, .preloader .bounce2, .preloader .bounce3 {
		background-color: <?php echo esc_attr( preslav_brightness( $primary_accent_color, -25 ) ); // WPCS: XSS ok. ?>;
	}
	@media (max-width: 54em) {
		.slide-menu, .site-menu.toggled > .menu-toggle {
			background-color:  <?php echo esc_attr( $primary_accent_color );?>;
		}
	}
	@media (min-width:54em){
		#secondary .tagcloud a:hover {
			background-color: <?php echo esc_attr( $secondary_accent_color ); ?>;
		}
	}

	.section-features figure::before {
		background: <?php echo esc_attr( $primary_accent_color ); ?>;
		opacity: .85;
	}
	</style>
	
	<?php
}

add_action( 'wp_head', 'preslav_customize_colors_css' );
