<?php

// Header Menu Position
function preslav_register_header_customizer( $wp_customize ) {

	$wp_customize->add_panel(
		'preslav_header_options',
		array(
			'title'       => esc_html__( 'Header Options', 'preslav' ),
			'description' => esc_html__( 'Customize the site header with the options below.', 'preslav' ),
		)
	);

	$wp_customize->add_section(
		'primary_menu',
		array(
			'title'       => esc_html__( 'Site Header', 'preslav' ),
			'description' => esc_html__( 'Customize the way the site header is displayed. To customize the header image, go to the header image section. You can configure the order of the items and the scrolling behavior.', 'preslav' ),
			'panel'       => 'preslav_header_options',
		)
	);
	$wp_customize->add_section(
		'secondary_menu',
		array(
			'title'       => esc_html__( 'Top Bar', 'preslav' ),
			'description' => esc_html__( 'Display a top bar menu on top of the site header and customize it accordingly. You can add business info to it, social icons, search icon, etc. You can also display a standard WordPress menu here by creating a menu and linking it to the "top menu" location. (appearance => menus)', 'preslav' ),
			'panel'       => 'preslav_header_options',
		)
	);

	// Header Presets
	$wp_customize->add_setting(
		'header-menu-presets',
		array(
			'default'           => 'left',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'header-menu-presets',
		array(
			'label'       => esc_html__( 'Header Presets', 'preslav' ),
			'section'     => 'primary_menu',
			'description' => esc_html__( ' Reorder the way header items (site title, site description, logo and primary menu) are displayed', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'left'   => is_rtl() ? esc_html__( 'right site title and logo', 'preslav' ) : esc_html__( 'left site title and logo', 'preslav' ),
				'center' => esc_html__( 'centered site title and logo', 'preslav' ),
				'right'  => is_rtl() ? esc_html__( 'left site title and logo', 'preslav' ) : esc_html__( 'right site title and logo', 'preslav' ),
			),
		)
	);

	$wp_customize->add_setting(
		'header-menu-position',
		array(
			'default'           => 'sticky',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'header-menu-position',
		array(
			'label'       => esc_html__( 'Header Position', 'preslav' ),
			'section'     => 'primary_menu',
			'description' => esc_html__( ' Position the header on top of the page (static position), show it while scrolling (fixed) or only show it when you scroll up (sticky). The default positon is sticky. ', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'fixed'  => esc_html__( 'fixed', 'preslav' ),
				'sticky' => esc_html__( 'sticky', 'preslav' ),
				'static' => esc_html__( 'static', 'preslav' ),
			),
		)
	);

	$wp_customize->add_setting(
		'homepage_has_transparent_header',
		array(
			'default'           => false,
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'homepage_has_transparent_header',
		array(
			'label'       => esc_html__( 'Enable Transparent Header on homepage. If you use this option, the site title and the site menu will become transparent. Enable on multiple pages - go pro version.', 'preslav' ),
			'section'     => 'primary_menu',
			'type'        => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'header-menu-alignment',
		array(
			'default'           => 'right',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'header-menu-alignment',
		array(
			'label'           => esc_html__( 'Site Header Text Alignment', 'preslav' ),
			'section'         => 'primary_menu',
			'description'     => esc_html__( 'Position the site title and the primary menu in relation to each other.', 'preslav' ),
			'type'            => 'select',
			'choices'         => array(
				'left'   => esc_html__( 'normal', 'preslav' ),
				'center' => esc_html__( 'center', 'preslav' ),
				'right'  => esc_html__( 'space between', 'preslav' ),
			),
			'active_callback' => function() {
				return get_theme_mod( 'header-menu-presets', 'left' ) !== 'center';
			},
		)
	);

	$wp_customize->add_setting(
		'has_underline',
		array(
			'default'           => 1,
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'has_underline',
		array(
			'label'       => esc_html__( 'Enable Current Menu Item Underline', 'preslav' ),
			'section'     => 'primary_menu',
			'type'        => 'checkbox',
		)
	);


	$wp_customize->add_setting(
		'menu_items_animation',
		array(
			'default'           => 'rollover',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'menu_items_animation',
		array(
			'label'       => esc_html__( 'Menu Item Hover Animation', 'preslav' ),
			'section'     => 'primary_menu',
			'description' => esc_html__( 'Choose an animation to display when hovering over a menu item. ', 'preslav' ),
			'type'        => 'select',
			'choices'     => array(
				'underline'   => esc_html__( 'Underline', 'preslav' ),
				'rollover' => esc_html__( 'Rollover', 'preslav' )
			)
		)
	);

	// Top menu
	$wp_customize->add_setting(
		'has_secondary_menu',
		array(
			'default'           => true,
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'has_secondary_menu',
		array(
			'label'       => esc_html__( 'Enable Top Menu', 'preslav' ),
			'description' => esc_html__( 'Display a top bar menu on top of the site header. Please note that on mobile this menu gets combined with the primary menu for better user experience.', 'preslav' ),
			'section'     => 'secondary_menu',
			'type'        => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'top-menu-alignment',
		array(
			'default'           => 'center',
			'sanitize_callback' => 'preslav_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'top-menu-alignment',
		array(
			'label'           => esc_html__( 'Top Bar Text Alignment', 'preslav' ),
			'section'         => 'secondary_menu',
			'description'     => esc_html__( ' Position the menu to the left, center or right side of the screen', 'preslav' ),
			'type'            => 'select',
			'choices'         => array(
				'left'   => esc_html__( 'left', 'preslav' ),
				'center' => esc_html__( 'center', 'preslav' ),
				'right'  => esc_html__( 'right', 'preslav' ),
			),
			'active_callback' => 'preslav_has_secondary_menu',
		)
	);

	$wp_customize->add_setting(
		'location',
		array(
			'default'           => 'My Street 12',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'location',
		array(
			'label'           => esc_html__( 'Address', 'preslav' ),
			'section'         => 'secondary_menu',
			'type'            => 'url',
			'description'     => esc_html__( 'Add your address', 'preslav' ),
			'active_callback' => 'preslav_has_secondary_menu',
		)
	);
	$wp_customize->add_setting(
		'phone_control',
		array(
			'default'           => '00123456789',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'phone_control',
		array(
			'label'           => esc_html__( 'Phone number', 'preslav' ),
			'section'         => 'secondary_menu',
			'type'            => 'url',
			'description'     => esc_html__( 'Add your phone number', 'preslav' ),
			'active_callback' => 'preslav_has_secondary_menu',
		)
	);

	$wp_customize->add_setting(
		'mail_control',
		array(
			'default'           => 'email@myemail.com',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'mail_control',
		array(
			'label'           => esc_html__( 'Email address', 'preslav' ),
			'section'         => 'secondary_menu',
			'type'            => 'url',
			'description'     => esc_html__( 'Add your mail address', 'preslav' ),
			'active_callback' => 'preslav_has_secondary_menu',
		)
	);

	$wp_customize->add_setting(
		'has_search',
		array(
			'default'           => 1,
			'transport'         => 'postMessage',
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'has_search',
		array(
			'label'           => esc_html__( 'Show Search Icon', 'preslav' ),
			'section'         => 'secondary_menu',
			'type'            => 'checkbox',
			'active_callback' => 'preslav_has_secondary_menu',
		)
	);

	$wp_customize->add_setting(
		'preslav_social_icons_setting',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new Preslav_Sortable_Repeater_Custom_Control(
			$wp_customize,
			'preslav_social_icons_setting',
			array(
				'label'           => esc_html__( 'Social Icons', 'preslav' ),
				'description'     => esc_html__( 'Add your social media links and their icons will automatically appear in the top bar menu. Drag and drop the urls to rearrange the order of the icons.', 'preslav' ),
				'section'         => 'secondary_menu',
				'button_labels'   => array(
					'add' => esc_html__( 'Add Row', 'preslav' ),
				),
				'active_callback' => 'preslav_has_secondary_menu',
			)
		)
	);

	$wp_customize->add_setting(
		'social_url_icons',
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Preslav_Single_Accordion_Custom_Control(
			$wp_customize,
			'social_url_icons',
			array(
				'label'           => esc_html__( 'View list of available social icons', 'preslav' ),
				'section'         => 'secondary_menu',
				'description'     => array(
					esc_html__( 'Behance', 'preslav' )    => preslav_get_svg( 'behance' ),
					esc_html__( 'Dribble', 'preslav' )    => preslav_get_svg( 'dribble' ),
					esc_html__( 'Facebook', 'preslav' )   => preslav_get_svg( 'facebook' ),
					esc_html__( 'Flickr', 'preslav' )     => preslav_get_svg( 'flickr' ),
					esc_html__( 'Github', 'preslav' )     => preslav_get_svg( 'github' ),
					esc_html__( 'Instagram', 'preslav' )  => preslav_get_svg( 'instagram' ),
					esc_html__( 'Linkedin', 'preslav' )   => preslav_get_svg( 'linkedin' ),
					esc_html__( 'Pinterest', 'preslav' )  => preslav_get_svg( 'pinterest' ),
					esc_html__( 'Snapchat', 'preslav' )   => preslav_get_svg( 'snapchat' ),
					esc_html__( 'Soundcloud', 'preslav' ) => preslav_get_svg( 'soundcloud' ),
					esc_html__( 'Tiktok', 'preslav' )     => preslav_get_svg( 'tiktok' ),
					esc_html__( 'Tumblr', 'preslav' )     => preslav_get_svg( 'tumblr' ),
					esc_html__( 'Twitch', 'preslav' )     => preslav_get_svg( 'twitch' ),
					esc_html__( 'Twitter', 'preslav' )    => preslav_get_svg( 'twitter' ),
					esc_html__( 'Youtube', 'preslav' )    => preslav_get_svg( 'youtube' ),
					esc_html__( 'WordPress', 'preslav' )  => preslav_get_svg( 'wordpress' ),
				),
				'active_callback' => 'preslav_has_secondary_menu',
			)
		)
	);

	$wp_customize->add_setting(
		'show_top_bar_icons_mobile',
		array(
			'default'           => false,
			'sanitize_callback' => 'preslav_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'show_top_bar_icons_mobile',
		array(
			'label'       => esc_html__( 'Show social icons on mobile.', 'preslav' ),
			'description' => esc_html__( 'Enable this if you want to display the social icons under the primary menu on mobile.', 'preslav' ),
			'section'     => 'secondary_menu',
			'type'        => 'checkbox',
			'active_callback' => 'preslav_has_secondary_menu',
		)
	);

}

add_action( 'customize_register', 'preslav_register_header_customizer' );

function preslav_customize_header_menu_options() {

	// get menu colors
	$header_text_color = get_theme_mod( 'preslav_header_text_color', '#000' );

	// static vs sticky header
	$header_menu_position = get_theme_mod( 'header-menu-position', 'sticky' );

	$top_menu_text_color = get_theme_mod( 'top-menu_text_color', '#334142' );
	$top_menu_bgr_color  = get_theme_mod( 'top-menu_bgr_color', '#fff' );
	$top_bar_height      = is_admin_bar_showing() ? '2rem' : '0';

	$header_menu_alignment = get_theme_mod( 'header-menu-alignment', 'right' );
	$top_menu_alignment    = get_theme_mod( 'top-menu-alignment', 'center' );
	$header_preset         = get_theme_mod( 'header-menu-presets', 'left' );

	$has_underline = get_theme_mod( 'has_underline', 1 );

	$menu_items_animation = get_theme_mod( 'menu_items_animation', 'rollover' );

	?>
	<style type="text/css">
	<?php if ( $header_menu_alignment == 'left' ) : ?>
	@media(min-width:54rem){
		.main-navigation-container .header-content-wrapper {
			justify-content: left;
		}
	}
	<?php elseif ( $header_menu_alignment == 'center' ) : ?>
	@media(min-width:54rem){
		.main-navigation {
			flex: 0 0 75%;
		}
	}
		<?php
	endif;

	if ( $top_menu_alignment == 'left' ) :
		?>
	@media(min-width:54rem){
		.top-menu ul {
			justify-content: left;
		}
	}
	<?php elseif ( $top_menu_alignment == 'right' ) : ?>
	@media(min-width:54rem){
		.top-menu ul {
			justify-content: right;
		}
	}
		<?php
	endif;

	if ( $header_preset == 'center' ) :
		?>
	.header-content-wrapper {
		display: block
	}
	.site-branding {
		justify-content: center;
		flex-direction: column;
	}
	.custom-logo-link {
		padding-top: 1rem;
		padding-bottom: 1rem;
	}
	.site-meta {
		text-align: center;
	}
	@media(max-width:54rem){
		.main-navigation > .menu-toggle {
			display: table;
			margin: auto;
		}
		.main-navigation.toggled > .menu-toggle {
			position: absolute;
			right: 1rem;
			top: 1.5rem;
		}
	}
	<?php elseif ( $header_preset == 'right' ) : ?>
	.site-branding {
		order: 1;
	}
	.custom-logo-link {
		order: 1;
		margin-left: 1rem;
		margin-right: 0;
	}
		<?php
		if ( $header_menu_alignment !== 'center' ) :
			if ( is_rtl() ) :
				?>
			.site-branding {
				justify-content: left;
			}
			<?php else : ?>
			.site-branding {
				justify-content: right;
			} ?>
				<?php
			endif;
		endif;
		?>
	.main-navigation.toggled > .menu-toggle {
		position: absolute;
		right: 1rem;
		top: 1.5rem;
	}
		<?php
	endif;

	if ( $header_menu_position == 'static' ) :  // static header

		?>
	.site-header a {
		color: <?php echo esc_attr( $header_text_color ); ?>;
	}
	.top-menu {
		background: <?php echo esc_attr( $top_menu_bgr_color ); ?>;
	}
	.top-menu a {
		color: <?php echo esc_attr( $top_menu_text_color ); ?>;
	}
	.top-menu .feather {
		stroke: <?php echo esc_attr( $top_menu_text_color ); ?>;
	}
	.main-navigation-container {
		background-color: #fff;
		position: relative;
		z-index: 9;
	}
	
	.menu-toggle .burger,
	.menu-toggle .burger:before,
	.menu-toggle .burger:after {
		border-bottom: 2px solid #333;
	}

	.has-transparent-header .main-navigation-container {
		position: absolute;
		background: transparent;
	}
	.has-transparent-header #primary-menu > li > a, 
	.has-transparent-header .site-title a, 
	.has-transparent-header .site-description {
		color: #fff;
	}

	.has-transparent-header:not(.dark-mode):not(.modal-open) .menu-toggle .burger, 
	.has-transparent-header:not(.dark-mode):not(.modal-open) .menu-toggle .burger::before, 
	.has-transparent-header:not(.dark-mode):not(.modal-open) .menu-toggle .burger::after {
		border-bottom: 2px solid #fff;
	}
	
		<?php
	else : // sticky header

		?>
	.main-navigation-container {
		background: transparent;
		<?php if ( preslav_has_transparent_header() ) : ?>
		position: fixed;
		<?php endif; ?>
		z-index: 1000;
	}

	.main-navigation-container.fixed-header {
		background-color: #fff;
	}

	.has-transparent-header .menu-toggle .burger,
	.has-transparent-header .menu-toggle .burger:before,
	.has-transparent-header .menu-toggle .burger:after {
		border-bottom: 2px solid #f7f7f7;
	}

	.has-transparent-header:not(.dark-mode) .fixed-header .menu-toggle .burger,
	.has-transparent-header:not(.dark-mode) .fixed-header .burger:before,
	.has-transparent-header:not(.dark-mode) .fixed-header .burger:after {
		border-bottom: 2px solid #333;
	}

	.has-transparent-header .toggled .menu-toggle .burger,
	.has-transparent-header .toggled .menu-toggle .burger:before,
	.has-transparent-header .toggled .menu-toggle .burger:after {
		border-bottom: 2px solid #f7f7f7;
	}


	.has-transparent-header .site-title a, .has-transparent-header p.site-description {
		color: #fff;
	}
	.has-transparent-header .fixed-header .site-title a, .has-transparent-header .fixed-header p.site-description,
	.site-title a, body p.site-description {
		color: <?php echo esc_attr( $header_text_color ); ?>;
	}

	.top-menu {
		background: <?php echo esc_attr( $top_menu_bgr_color ); ?>;
	}

	.top-menu a {
		color: <?php echo esc_attr( $top_menu_text_color ); ?>;
	}

	.top-menu .feather {
		stroke: <?php echo esc_attr( $top_menu_text_color ); ?>;
	}

	.fixed-header {
		top: 0;
	}

	@media (min-width: 54rem) {
		.has-transparent-header .main-navigation a {
			color: #fff;
		}
		.has-transparent-header .main-navigation .feather {
			stroke: #fff;
		}
		.fixed-header {
			top: <?php echo esc_attr( $top_bar_height ); ?>
		}
		.has-transparent-header .fixed-header .main-navigation a {
			color: <?php echo esc_attr( $header_text_color ); ?>;
		}
		.has-transparent-header .fixed-header .main-navigation .feather {
			stroke: <?php echo esc_attr( $header_text_color ); ?>;
		}
		.main-navigation a {
			color: <?php echo esc_attr( $header_text_color ); ?>;
		}
		.has-transparent-header .main-navigation ul ul a {
			color: <?php echo esc_attr( $header_text_color ); ?>;
		}
	}

		<?php
	endif;

	// Menu Items Current Menu Item Underline
	if ( $has_underline ) : ?>
	@media (min-width: 54rem) {
		#primary-menu > .current_page_item > a > span {
			background: linear-gradient(to right, CurrentColor 0%, CurrentColor 100%);
			background-size: 100% 2px;
			background-repeat: no-repeat;
			background-position: left 100%;
		}
	}
	<?php endif;

	// Menu Items hover animation 
	if ( $menu_items_animation == 'underline' ) : ?>
	@media (min-width: 54rem) {
		#primary-menu > li > a > span{
			background: linear-gradient(to right, CurrentColor 0%, CurrentColor 100%);
			background-size: 0 2px;
			background-repeat: no-repeat;
			background-position: left 100%;
			display: inline-block;
			transition: background-size 0.6s ease-in-out;
		}

		#primary-menu > li > a > span:hover {
			background-size: 100% 2px;
		}
	}
	<?php endif; ?>

	<?php if ($menu_items_animation == 'rollover') : ?>
	@media (min-width: 54rem) {
		#primary-menu > li > a {
			position: relative;
			padding: 0 1rem;
			margin: 0.75rem 0;
			overflow: hidden;
			display: block;
			text-align: center;
		}
		#primary-menu > li > a span {
			display: block;
			transition: transform 700ms cubic-bezier(0.68, -0.55, 0.265, 1.55);
		}
		#primary-menu > li > a:before {
			content: attr(data-text);
			display: inline;
			position: absolute;
			transition: top 700ms cubic-bezier(0.68, -0.55, 0.265, 1.55);
			top: 100%;
			left: 0;
			right: 0;
			text-align: center;
			font-size: inherit
		}
		#primary-menu > li > a:hover span {
			transform: translateY(-100%);
		}
		#primary-menu > li > a:hover:before {
			top: 0;
		}

		#primary-menu > li.page_item_has_children > a::after, 
		#primary-menu > li.menu-item-has-children > a::after {
			position: absolute;
			<?php echo is_rtl() ? esc_attr( 'left: .35rem;' ) : esc_attr( 'right: .35rem;' ); ?>
			top: .65rem;
		}

		<?php endif; ?>
	}
	</style>
	<?php
}

add_action( 'wp_head', 'preslav_customize_header_menu_options' );
