<?php

/*
 ** Allow users to change page layout via Theme Customizer
 */

function preslav_register_theme_layout_options( $wp_customize ) {

	$wp_customize->add_panel(
		'preslav_layout_options',
		array(
			'title'       => esc_html__( 'Page Layout', 'preslav' ),
			'description' => esc_html__( 'Set custom width for the header, container and the footer. Display post archives in multi-column layout.', 'preslav' ),
		)
	);

	$wp_customize->add_section(
		'header_layout',
		array(
			'title'       => esc_html__( 'Header Layout', 'preslav' ),
			'description' => esc_html__( 'Set custom width for the header.', 'preslav' ),
			'panel'       => esc_html__( 'preslav_layout_options', 'preslav' ),
		)
	);

	$wp_customize->add_section(
		'container_layout',
		array(
			'title'       => esc_html__( 'Container Layout', 'preslav' ),
			'description' => esc_html__( 'Set custom width for posts and pages. Display post archives in multi-column layout.', 'preslav' ),
			'panel'       => esc_html__( 'preslav_layout_options', 'preslav' ),
		)
	);

	$wp_customize->add_section(
		'footer_layout',
		array(
			'title'       => esc_html__( 'Footer Layout', 'preslav' ),
			'description' => esc_html__( 'Set custom width for the footer.', 'preslav' ),
			'panel'       => esc_html__( 'preslav_layout_options', 'preslav' ),
		)
	);

	// Header
	$wp_customize->add_setting(
		'header_width',
		array(
			'default'           => '1196',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		new Preslav_Range_Slider_Control(
			$wp_customize,
			'header_width',
			array(
				'type'     => 'preslav-range-slider',
				'label'    => __( 'Header Width', 'preslav' ),
				'section'  => 'header_layout',
				'settings' => array(
					'desktop' => 'header_width',
				),
				'choices'  => array(
					'desktop' => array(
						'min'  => 700,
						'max'  => 2000,
						'step' => 5,
						'edit' => true,
						'unit' => 'px',
					),
				),
			)
		)
	);

	// Container
	$wp_customize->add_setting(
		'container_width',
		array(
			'default'           => '980',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		new Preslav_Range_Slider_Control(
			$wp_customize,
			'container_width',
			array(
				'type'        => 'preslav-range-slider',
				'label'       => __( 'Page Content Width', 'preslav' ),
				'description' => __( 'Adjust the width of the page container', 'preslav' ),
				'section'     => 'container_layout',
				'settings'    => array(
					'desktop' => 'container_width',
				),
				'choices'     => array(
					'desktop' => array(
						'min'  => 700,
						'max'  => 2000,
						'step' => 5,
						'edit' => true,
						'unit' => 'px',
					),
				),
			)
		)
	);

	$wp_customize->add_setting(
		'post_container_width',
		array(
			'default'           => '860',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		new Preslav_Range_Slider_Control(
			$wp_customize,
			'post_container_width',
			array(
				'type'        => 'preslav-range-slider',
				'label'       => __( 'Post Content Width', 'preslav' ),
				'description' => __( 'Adjust the width of the container in single posts and post archives', 'preslav' ),
				'section'     => 'container_layout',
				'settings'    => array(
					'desktop' => 'post_container_width',
				),
				'choices'     => array(
					'desktop' => array(
						'min'  => 700,
						'max'  => 2000,
						'step' => 5,
						'edit' => true,
						'unit' => 'px',
					),
				),
			)
		)
	);

	// Footer

	$wp_customize->add_setting(
		'footer_width',
		array(
			'default'           => '1180',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		new Preslav_Range_Slider_Control(
			$wp_customize,
			'footer_width',
			array(
				'type'     => 'preslav-range-slider',
				'label'    => __( 'Footer Width', 'preslav' ),
				'section'  => 'footer_layout',
				'settings' => array(
					'desktop' => 'footer_width',
				),
				'choices'  => array(
					'desktop' => array(
						'min'  => 700,
						'max'  => 2000,
						'step' => 5,
						'edit' => true,
						'unit' => 'px',
					),
				),
			)
		)
	);

}

add_action( 'customize_register', 'preslav_register_theme_layout_options' );

function preslav_customize_css() {
	$header_wrapper = get_theme_mod( 'header_width', 1196 );
	$wrapper        = get_theme_mod( 'container_width', 980 );
	$post_wrapper   = get_theme_mod( 'post_container_width', 860 );
	$footer_wrapper = get_theme_mod( 'footer_width', 1180 );

	$cursor_layout = get_theme_mod( 'cursor_layout', 'transparent' );
	?>

<style type="text/css">
	.header-content-wrapper {
		max-width: <?php echo esc_attr( $header_wrapper ); ?>px;
	}
	.page .site-wrapper, .woocommerce .site-wrapper {
		max-width: <?php echo esc_attr( $wrapper ); ?>px;
	}
	.site-wrapper {
		max-width: <?php echo esc_attr( $post_wrapper ); ?>px;
	}
	.footer-content {
		max-width: <?php echo esc_attr( $footer_wrapper ); ?>px;
	}

</style>

	<?php

}
add_action( 'wp_head', 'preslav_customize_css' );
