<?php
/**
 * Add selective refresh and postMessage support for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function preslav_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'preslav_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'preslav_customize_partial_blogdescription',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'location',
			array(
				'selector'            => '.location',
				'fallback_refresh'    => true,
				'container_inclusive' => true,
				'render_callback'     => 'preslav_customize_partial_location',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'phone_control',
			array(
				'selector'            => '.phone',
				'fallback_refresh'    => false,
				'container_inclusive' => true,
				'render_callback'     => 'preslav_customize_partial_phone',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'mail_control',
			array(
				'selector'            => '.mail',
				'fallback_refresh'    => true,
				'container_inclusive' => true,
				'render_callback'     => 'preslav_customize_partial_mail',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'has_search',
			array(
				'selector'            => '.search-icon',
				'fallback_refresh'    => true,
				'container_inclusive' => true,
				'render_callback'     => 'preslav_customize_partial_search_icon',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'enable_dark_mode',
			array(
				'selector'            => '.dark-mode-menu-item',
				'fallback_refresh'    => true,
				'render_callback'     => 'preslav_customize_partial_dark_mode',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'header_background_position',
			array(
				'selector'            => '.header-image-wrapper',
				'render_callback'  => '__return_false',
				'fallback_refresh' => false,

			)
		);

	}
}
add_action( 'customize_register', 'preslav_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function preslav_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function preslav_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/* Render top menu with selective refresh */

function preslav_customize_partial_location() {
	preslav_location_icon();
}

function preslav_customize_partial_phone() {
	preslav_phone_icon();
}

function preslav_customize_partial_mail() {
	preslav_mail_icon();
}

function preslav_customize_partial_search_icon() {
	preslav_search_icon();
}

function preslav_customize_partial_dark_mode(){
	preslav_primary_menu_dark_mode_markup();
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function preslav_customize_preview_js() {
	wp_enqueue_script( 'preslav-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), PRESLAV_VERSION, true );
	wp_enqueue_style( 'preslav-customizer', get_template_directory_uri() . '/assets/css/customizer.css', array( 'customize-preview' ), PRESLAV_VERSION );
}
add_action( 'customize_preview_init', 'preslav_customize_preview_js' );
