<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package preslav
 */

if ( ! function_exists( 'preslav_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function preslav_posted_on( $show_post_published_date ) {

		if ( $show_post_published_date || is_customize_preview() ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf(
				$time_string,
				esc_attr( get_the_date( DATE_W3C ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( DATE_W3C ) ),
				esc_html( get_the_modified_date() )
			);

			$posted_on = sprintf(
				/* translators: %s: post date. */
				wp_kses( preslav_get_svg( 'calendar' ), preslav_get_kses_extended_ruleset() ) .
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);

			echo '<span class="posted-on ' . preslav_add_customizer_class( $show_post_published_date ) . '">' . $posted_on . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}
endif;

if ( ! function_exists( 'preslav_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function preslav_posted_by( $show_post_author ) {
		if ( $show_post_author || is_customize_preview() ) {
			$byline = sprintf(
				/* translators: %s: post author. */
				esc_html_x( 'by%s', 'post author', 'preslav' ),
				'<span class="author vcard"><a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);

			echo '<span class="byline ' . preslav_add_customizer_class( $show_post_author ) . '"> ' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}
endif;

  /**
  * Print edit button for logged-in editors
  */
if ( ! function_exists( 'preslav_edit_link' ) ) :

	function preslav_edit_link() {

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'preslav' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				wp_kses_post( get_the_title() )
			),
			'<span class="edit-link">',
			'</span>'
		);

	}
endif;

if ( ! function_exists( 'preslav_posted_in' ) ) :
	function preslav_posted_in( $display_category_list ) {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'preslav' ) );
			if ( ( $categories_list && $display_category_list ) || is_customize_preview() ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links ' . preslav_add_customizer_class( $display_category_list ) . '">' . wp_kses( preslav_get_svg( 'folder' ), preslav_get_kses_extended_ruleset() ) . $categories_list . '</span>' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		}
	}
endif;

if ( ! function_exists( 'preslav_tagged_in' ) ) :
	function preslav_tagged_in( $display_tag_list ) {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'preslav' ) );
			if ( ( $tags_list && $display_tag_list ) || is_customize_preview() ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tag-links ' . preslav_add_customizer_class( $display_tag_list ) . '">' . wp_kses( preslav_get_svg( 'tag' ), preslav_get_kses_extended_ruleset() ) . $tags_list . '</span>' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		}
	}
endif;

if ( ! function_exists( 'preslav_display_comments' ) ) :
	function preslav_display_comments( $display_comments ) {
		if ( $display_comments || is_customize_preview() ) {
			if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
				echo '<span class="comments-link ' . preslav_add_customizer_class( $display_comments ) . '">';
				comments_popup_link(
					sprintf(
						wp_kses(
							/* translators: %s: post title */
							__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'preslav' ),
							array(
								'span' => array(
									'class' => array(),
								),
							)
						),
						wp_kses_post( get_the_title() )
					)
				);
				echo '</span>';
			}
		}
	}
endif;

if ( ! function_exists( 'preslav_entry_header' ) ) :
	/**
	 * Prints HTML with meta information before the post content
	 */
	function preslav_entry_header() {
		$post_meta_list = preslav_get_post_meta_before_post_content();

		$date            = in_array( 'show_post_date', preslav_get_post_meta_before_post_content(), true );
		$author          = in_array( 'show_post_author', preslav_get_post_meta_before_post_content(), true );
		$categories_list = in_array( 'show_post_categories', preslav_get_post_meta_before_post_content(), true );
		$tags_list       = in_array( 'show_post_tags', preslav_get_post_meta_before_post_content(), true );
		$comments        = in_array( 'show_post_comments', preslav_get_post_meta_before_post_content(), true );

		for ( $i = 0; $i < count( $post_meta_list ); $i++ ) :

			switch ( $post_meta_list[ $i ] ) :
				case 'show_post_date':
					preslav_posted_on( $date );
					break;
				case 'show_post_author':
					preslav_posted_by( $author );
					break;
				case 'show_post_categories':
					preslav_posted_in( $categories_list );
					break;
				case 'show_post_tags':
					preslav_tagged_in( $tags_list );
					break;
				case 'show_post_comments':
					preslav_display_comments( $comments );
					break;
			endswitch;

		endfor;

	}
endif;

if ( ! function_exists( 'preslav_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information after post content
	 */
	function preslav_entry_footer() {
		$post_meta_list = preslav_get_post_meta_after_post_content();

		$date            = in_array( 'show_post_date', preslav_get_post_meta_after_post_content(), true );
		$author          = in_array( 'show_post_author', preslav_get_post_meta_after_post_content(), true );
		$categories_list = in_array( 'show_post_categories', preslav_get_post_meta_after_post_content(), true );
		$tags_list       = in_array( 'show_post_tags', preslav_get_post_meta_after_post_content(), true );
		$comments        = in_array( 'show_post_comments', preslav_get_post_meta_after_post_content(), true );

		for ( $i = 0; $i < count( $post_meta_list ); $i++ ) :

			switch ( $post_meta_list[ $i ] ) :
				case 'show_post_date':
					preslav_posted_on( $date );
					break;
				case 'show_post_author':
					preslav_posted_by( $author );
					break;
				case 'show_post_categories':
					preslav_posted_in( $categories_list );
					break;
				case 'show_post_tags':
					preslav_tagged_in( $tags_list );
					break;
				case 'show_post_comments':
					preslav_display_comments( $comments );
					break;
			endswitch;

		endfor;
	}
endif;

if ( ! function_exists( 'preslav_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function preslav_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
					the_post_thumbnail(
						'post-thumbnail',
						array(
							'alt' => the_title_attribute(
								array(
									'echo' => false,
								)
							),
						)
					);
				?>
			</a>

			<?php
		endif; // End is_singular().
	}
endif;

/**
 * Adds a Sub Nav Toggle Button to the Mobile Menu.
 *
 * @param stdClass $args  An object of wp_nav_menu() arguments.
 * @param WP_Post  $item  Menu item data object.
 * @param int      $depth Depth of menu item. Used for padding.
 * @return stdClass An object of wp_nav_menu() arguments.
 */
function preslav_add_sub_toggles_to_main_menu( $args, $item, $depth ) {
	// Add sub menu toggles to the Expanded Menu with toggles.
	if ( isset( $args->show_toggles ) ) {

		$args->after = '';

		// Add a toggle to items with children.
		if ( in_array( 'menu-item-has-children', $item->classes, true ) || in_array( 'page_item_has_children', $item->classes, true ) ) {

			// Add the sub menu toggle.
			$args->after .= '<button class="menu-toggle sub-menu-toggle" aria-expanded="false">' . '<i class="arrow-down"></i>' . '<span class="screen-reader-text">' . __( 'Show sub menu', 'preslav' ) . '</span></button>';

		}
	}

	return $args;

}

add_filter( 'nav_menu_item_args', 'preslav_add_sub_toggles_to_main_menu', 10, 3 );

/* Primary Menu */

function preslav_primary_menu_dark_mode_markup() {
	$isDarkMode = get_theme_mod( 'enable_dark_mode', 1 ) == 1;

	if ( $isDarkMode ) :
		?>
		<li class="dark-mode-menu-item">
		<?php preslav_dark_mode_button_markup(); ?>
		</li>
		<?php
	endif;
}

/**
 * Top Bar Menu
 */

function preslav_location_icon() {
	$location = get_theme_mod( 'location', 'My Street 12' );

	if ( $location ) :
		?>
		<li class="social-icon">
			<a href="#">
				<?php
				echo sprintf(
				/* translators: %s: location */
					'%s&nbsp;' . esc_html__( '%s', 'preslav' ),
					wp_kses( preslav_get_svg( 'map-pin' ), preslav_get_kses_extended_ruleset() ),
					$location
				);
				?>
			</a>
		</li>
		 <?php
	 endif;
}

function preslav_phone_icon() {
	$phone = get_theme_mod( 'phone_control', '00123456789' );

	if ( $phone ) :
		?>
		<li class="social-icon">
			<a href="tel:<?php echo esc_attr( $phone ); ?>">
				<?php echo wp_kses( preslav_get_svg( 'phone' ), preslav_get_kses_extended_ruleset() ) . '&nbsp;' . esc_html( $phone ); ?>
			</a>
		</li>
		 <?php
	 endif;
}

function preslav_mail_icon() {
	$mail = get_theme_mod( 'mail_control', 'email@myemail.com' );

	if ( $mail ) :
		?>
		<li class="social-icon">
			<a href="mailto:<?php echo esc_attr( $mail ); ?>">
				<?php echo wp_kses( preslav_get_svg( 'mail' ), preslav_get_kses_extended_ruleset() ) . '&nbsp;' . esc_html( $mail ); ?>
			</a>
		</li>
		 <?php
	 endif;
}

function preslav_search_icon() {
	$has_search = get_theme_mod( 'has_search', 1 );
	if ( $has_search ) :
		preslav_add_search_box();
	 endif;
}

function preslav_wc_icons() {
	do_action( 'preslav_fixed_menu_hook' );
}

function preslav_secondary_menu_markup() {

	$social_urls      = get_theme_mod( 'preslav_social_icons_setting' );
	$social_urls_list = explode( ',', $social_urls );

	preslav_location_icon();

	preslav_phone_icon();

	preslav_mail_icon();

	foreach ( $social_urls_list as $url ) :
		if ( empty( $url ) ) {
			continue;
		}
		// get the domain name from url
		$domain_name = str_ireplace( 'www.', '', parse_url( $url, PHP_URL_HOST ) );
		$domain      = explode( '.', $domain_name )[0];
		?>
		<li class="social-icon">
			<a href="<?php echo esc_url( $url ); ?>">
		<?php
		switch ( $domain ) :
			case 'facebook':
				echo wp_kses( preslav_get_svg( 'facebook' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'instagram':
				echo wp_kses( preslav_get_svg( 'instagram' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'twitter':
				echo wp_kses( preslav_get_svg( 'twitter' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'linkedin':
				echo wp_kses( preslav_get_svg( 'linkedin' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'youtube':
				echo wp_kses( preslav_get_svg( 'youtube' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'pinterest':
				echo wp_kses( preslav_get_svg( 'pinterest' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'wordpress': // phpcs:ignore WordPress.WP.CapitalPDangit.Misspelled
				echo wp_kses( preslav_get_svg( 'wordpress' ), preslav_get_kses_extended_ruleset() ); // phpcs:ignore WordPress.WP.CapitalPDangit.Misspelled
				break;
			case 'behance':
				echo wp_kses( preslav_get_svg( 'behance' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'dribble':
				echo wp_kses( preslav_get_svg( 'dribble' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'flickr':
				echo wp_kses( preslav_get_svg( 'flickr' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'github':
				echo wp_kses( preslav_get_svg( 'github' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'soundcloud':
				echo wp_kses( preslav_get_svg( 'soundcloud' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'snapchat':
				echo wp_kses( preslav_get_svg( 'snapchat' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'tiktok':
				echo wp_kses( preslav_get_svg( 'tiktok' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'twitch':
				echo wp_kses( preslav_get_svg( 'twitch' ), preslav_get_kses_extended_ruleset() );
				break;
			case 'tumblr':
				echo wp_kses( preslav_get_svg( 'tumblr' ), preslav_get_kses_extended_ruleset() );
				break;
			default:
				echo wp_kses( preslav_get_svg( 'globe' ), preslav_get_kses_extended_ruleset() );
				break;

		endswitch;
		?>
			</a>
		</li>
		<?php
	endforeach;

	preslav_search_icon();

	preslav_wc_icons();

}

/**
 * Dark Mode Toggle Button Html markup
 **/

function preslav_dark_mode_button_markup() {
	?>
	<button aria-label="Click to toggle dark mode" class="dark-mode-widget">
	   <?php echo wp_kses( preslav_get_svg( 'sun' ), preslav_get_kses_extended_ruleset() ); ?>
	   <?php echo wp_kses( preslav_get_svg( 'moon' ), preslav_get_kses_extended_ruleset() ); ?>
	</button>
	<?php
	preslav_dark_mode_loader();
}

// Print the menu icons

function preslav_add_menu_icons( $items, $args ) {

	// if top menu
	if ( $args->theme_location == 'menu-1' ) {
		ob_start();
		preslav_primary_menu_dark_mode_markup();
		$items .= ob_get_clean();
		return $items;
	} // if primary menu
	elseif ( $args->theme_location == 'menu-2' ) {
		ob_start();
		preslav_secondary_menu_markup();
		$items .= ob_get_clean();
		return $items;
	} else {
		return $items;
	}
}

add_filter( 'wp_nav_menu_items', 'preslav_add_menu_icons', 1, 20 );

function preslav_primary_menu_object( $items, $args ) {
		ob_start();
		preslav_primary_menu_dark_mode_markup();
		$items .= ob_get_clean();
		return $items;
}

add_filter( 'wp_list_pages', 'preslav_primary_menu_object', 10, 2 );

/* Add search list item to top menu bar */
function preslav_add_search_box() {
	?>
	<li class="search-icon">
		<a href="#search-open">
			<?php echo wp_kses( preslav_get_svg( 'search' ), preslav_get_kses_extended_ruleset() ); ?>
		</a>
	</li>
	<?php
}

/* Full Screen Search */
function preslav_full_screen_search() {
	?>
	<div id="search-open">
		<div class="search-box-wrap">
			<div class="header-search-form">
				<?php
				get_search_form();
				?>
			</div>
		</div>
		<a href="#search-close" class="close">
			<button class="close-btn" tabindex="-1" aria-label="<?php _e( 'close', 'preslav' ); ?>">
			<?php
			echo wp_kses( preslav_get_svg( 'close' ), preslav_get_kses_extended_ruleset() );
			?>
	</button>
		</a>
	</div>
	<a href="#search-close" class="search-close"></a>
	<?php
}


function preslav_footer_default_theme_credits() {
	esc_html_e( 'Designed by', 'preslav' );
	?>
		<a href="<?php echo esc_url( __( 'https://nasiothemes.com/', 'preslav' ) ); ?>" class="imprint">
			<?php esc_html_e( 'Nasio Themes', 'preslav' ); ?>
		</a>
		<span class="sep"> || </span>
		<?php
		/* translators: %s: CMS name, i.e. WordPress. */
		esc_html_e( 'Powered by', 'preslav' );
		?>
		<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'preslav' ) ); ?>" class="imprint">
			<?php esc_html_e( 'WordPress', 'preslav' ); ?>
		</a>
	<?php
}

/**
 * Back to top
 */
function preslav_back_to_top() {
	if ( ! get_theme_mod( 'has_back_to_top', 1 ) ) {
		return;
	}
	?>
	<button class="back-to-top">
		<?php echo wp_kses( preslav_get_svg( 'arrow-double-up' ), preslav_get_kses_extended_ruleset() ); ?>
	</button>
	<?php
}

function preslav_progress_bar() {
	if ( is_single() && get_theme_mod( 'has_progress_bar', true ) ) :
		?>
		<div class="scroll-bar">
			<div class="progress-container">
				<div class="progress-bar" id="progressBar"></div>
			</div>  
		</div>
		<?php
	endif;
}

function preslav_header_image() {
	$title       = get_theme_mod( 'preslav_header_title', __( 'CREATE A WEBSITE THAT CONVERTS', 'preslav' ) );
	$description = get_theme_mod( 'preslav_header_description', __( 'Making the first step has never been easy', 'preslav' ) );
	$button      = get_theme_mod( 'call_to_action', __( 'Get Started', 'preslav' ) );
	$button_link = get_theme_mod( 'banner_link_one', '#' );
	$animation   = get_theme_mod( 'enable_header_text_animation', 1 );

	if ( has_header_image() && is_front_page() ) :
		?>

		<div class="header-image-wrapper">
			<?php if ( $title || $description || $button ) : ?> 
			<div class="header-image-container">
				<h1 class="<?php echo esc_attr( $animation ? 'p-animation-scale-change' : '' ); ?>"><?php echo esc_html( $title ); ?></h1>
				<p class="<?php echo esc_attr( $animation ? 'p-typewrite-animation' : '' ); ?>"><?php echo esc_html( $description ); ?></h1>
				<?php if ( $button || $button_link ) : ?>
				<div class ="btn-wrapper">
					<div class="wp-block-button <?php echo esc_attr( $animation ? 'p-btn-animation-rollover' : '' ); ?>">
						<a href="<?php echo esc_attr( $button_link ); ?>" class="wp-block-button__link <?php echo esc_attr( $animation ? 'slider-button' : '' ); ?> wp-element-button"><?php echo esc_html( $button ); ?></a>
					</div>
				</div>
				<?php endif; ?>
			</div>
			<?php endif; ?>
		</div>
		<?php
	endif;
}